# coding:utf-8

"""
sDSM (small Disk Space Monitor)

This file is part of sDSM.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

__author__ = "Christian Schwamborn <cs@mail.architektur.tu-darmstadt.de>"
__copyright__ = "Copyright (c) 2016 Christian Schwamborn"
__license__ = "GPL v.3"


# TODO: handle attachments

import smtplib
# python 2.6
from email.mime.text import MIMEText
# python 2.5
# from email.MIMEText import MIMEText


class SmtpError(Exception):
	"""Indicates a SMTP errors"""
	pass


class SmtpMail():

	var_names = ('host', 'port', 'security',
		'user', 'pwd', 'sender', 'recipient')

	def __init__(self, logger=None, **kwargs):

		# setup logger
		if logger:
			self.logger = logger
		else:
			self.logger = self.__dummyLogger()

		self.__setOpts(**kwargs)

		# fill in the blanks
		for k in self.var_names:
			try:
				getattr(self, k)
			except AttributeError:
				setattr(self, k, None)


	class __dummyLogger():

		def debug(self, *args): pass
		info = debug
		warn = debug
		warning = debug
		error = debug
		crit = debug
		critical = debug


	def __setOpts(self, **kwargs):

		for k, v in kwargs.iteritems():
			if k not in self.var_names:
				self.logger.error('unknown option: {0}'.format(k))
				continue
			setattr(self, k, v)


	def send(self, subj, msg, **kwargs):

		self.__setOpts(**kwargs)
		self.logger.debug('sending email to: {0}'.format(self.recipient))

		for k in ('host', 'sender', 'recipient'):
			if not getattr(self, k):
				raise SmtpError('refuse to send mail with an empty \'{0}\''.format(k))

		# prepare email
		msg = MIMEText(msg)
		msg['Subject'] = subj
		msg['From'] = self.sender
		msg['To'] = ", ".join(self.recipient)

		# connect, send and disconnect
		try:
			if self.security == 'ssl':
				smtp = smtplib.SMTP_SSL(self.host, self.port)
			else:
				smtp = smtplib.SMTP(self.host, self.port)
				if self.security == 'tls':
					smtp.starttls()

			if self.user and self.pwd:
				smtp.login(self.user, self.pwd)

			smtp.sendmail(self.sender, self.recipient, msg.as_string())
			smtp.close()
			self.logger.debug('done sending email')

		except Exception as e:
			self.logger.error('sending email failed: {0}'.format(e))

